@@ -23,14 +23,15 @@ class CVTrafficRegenerator(object):
     def _get_changed_apis(self):
         return OpenApiSpecDiff.OpenApiSpecDiff(self.apispec_one_path, self.apispec_two_path).diff
 
-    def _process_event_data(self, events, apis_to_check=[]):
+    def _process_event_data(self, apis_to_check=[]):
         cv_requests = []
+        events = self.ceobj.get_all_raw_events(apis_to_check)
         for event in events:
-            # print(event["attributes"]["http_path"])
+            #print("....."+str(event))
+            #print(event["attributes"]["http_path"])
             iflag = False
             # params_to_add = []
             for _ in apis_to_check:
-                # print("......." + str(_))
                 if str(_).lower() in str(event["attributes"]["http_path"]).lower():
                     iflag = True
                     params_to_add = apis_to_check[_]
@@ -70,7 +71,7 @@ class CVTrafficRegenerator(object):
         return cv_requests
 
     def _trigger_requests(self, cv_requests):
-        print("Regenerating traffic from CloudVector events....")
+        print("\n\nRegenerating traffic from CloudVector events....")
         for cv_request in cv_requests:
             print("------------" * 20)
             print("\nRecreating the request: " + str(cv_request))
@@ -80,9 +81,10 @@ class CVTrafficRegenerator(object):
             print("------------" * 20)
 
     def regenerate_traffic(self, changed_apis):
-        cv_events = self.get_captured_events()
+        #cv_events = self.get_captured_events()
         # print(changed_apis["changed"])
-        cv_requests = self._process_event_data(cv_events, changed_apis["changed"])
+        print("\nQuerying for events from APIShark.....")
+        cv_requests = self._process_event_data(changed_apis["changed"])
         # print("\n\n\n\n\n" + str(cv_requests))
         self._trigger_requests(cv_requests)
         print("------------" * 20)
